#!/bin/bash

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/landsat_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "landsat_setenv.txt was not found. You must put landsat_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

if [ `g.mlist type=rast pattern=${PRODUCT_NAME}*_BQA | wc -l` -eq 0 ]; then
	g.message -e "No LANDSAT images was found."
	exit 1
fi


for I in `g.mlist type=rast pattern=${PRODUCT_NAME}*_BQA`; do

	g.rename rast=$I,QA_${I}

done

for I in `g.mlist type=rast pattern="QA_*"`; do

	PATHROWDATE=`echo $I | awk '{print substr($1,7,13)}'`
	echo $PATHROWDATE
	echo ${PRODUCT_NAME}${PATHROWDATE}

	for B in `g.mlist type=rast pattern="${PRODUCT_NAME}${PATHROWDATE}*"`; do

		g.region rast=${B}
		OUTPUTNAME=`echo $B | awk -F"_" '{PREFIX = "temp_" substr($1,4,13); BAND = $2; sub(/B/, "_band", BAND); print PREFIX BAND}'`
		echo $OUTPUTNAME
		r.mapcalc "${OUTPUTNAME}=if($I==1 || $I==0,null(),if($I&32768,null(),$B))"
		if [ $? -ne 0 ]; then
			exit 1
		fi

	done
done

#
# merge images of same date and same band.
#
DLIST=`g.mlist type=rast pattern="temp_*" | cut -c 12-18 | sort | uniq`
BLIST=`g.mlist type=rast pattern="temp_*" | cut -d '_' -f 3 | sort | uniq`

for D in $DLIST; do

	for B in $BLIST; do
		ILIST=`g.mlist type=rast pattern="temp_*${D}_${B}" separator=comma`
		OUTPUTNAME=${PRODUCT_NAME}.A${D}_${B}
		if [ `echo $ILIST | wc -w` -eq 1 ]; then
			g.copy rast=${ILIST},${OUTPUTNAME}
		elif [ `echo $ILIST | wc -w` -gt 1 ]; then
			g.region rast=$ILIST
			r.patch output=${OUTPUTNAME} input=$ILIST
		else
			g.message -w "No image of DATE = $D , BAND = $B was found."
		fi
		r.colors map=${OUTPUTNAME} color=grey
	done

done

g.mremove -f rast="temp_*"
