#!/bin/bash

if [ $# != 3 ]; then
	echo "modis_disphist usage: [mapset of training area raster] [MODIS image date] [class No]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi


TRAINING=$1
DATE=$2
CLASS=$3

eval `g.findfile element=CELL file=$TRAINING`
if [ -z $file ]; then
	g.message -e "Training area raster layer was not found [ ${TRAINING} ]"
	exit 1
fi

if [ `g.mlist pattern="interp_${PRODUCT_NAME}.A"${DATE}* | wc -l` -eq 0 ]; then
	g.message -e "No layers of target date was not found [ ${DATE} ]"
	exit 1
fi

if [ -z `r.describe -1 -n map=${TRAINING} 2>/dev/null | grep ${CLASS}` ]; then
	g.message -e "CLASS No ${CLASS} was not found in the training area layer [ ${TRAINING} ]."
	exit 1
fi

LIST=`g.mlist pattern="interp_${PRODUCT_NAME}.A"${DATE}*`

r.mask input=${TRAINING} maskcats=${CLASS}
mkdir temp_ta
cd temp_ta

for I in $LIST; do

	echo $I
	r.out.xyz input=$I outpu=${I}".csv" fs=","
	if [ $? -ne 0 ]; then
		exit 1
	fi

done

g.remove rast=MASK > /dev/null
LIST=`g.mlist pattern="interp_${PRODUCT_NAME}.A"${DATE}* separator=comma`

$R_BIN --vanilla --slave << EOF

	win.graph( 80, 80 )
	par( mfrow=c(4,3) )
	LIST_ARR = strsplit( "$LIST", "," )

	for ( I in LIST_ARR[[1]] )
	{
		OBNAME <- paste( I, "DAT", sep="" )
		FNAME <- paste( I, ".csv", sep="" )
		TITLENAME <- strsplit( I, "_" )[[1]][3]
		DATA <- read.csv( FNAME )
		assign( OBNAME, DATA )
		hist( DATA[[3]], br="FD", main=TITLENAME, sub="", xlab="", ylab="",
			border="darkblue", col="lightblue" )
	}
	locator()
EOF

cd ..
rm -r -f temp_ta
