#!/bin/bash

if [ $# != 1 ]; then
	echo "modis_export_kml usage: [outpu file prefix]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

PREFIX=$1

LIST=`g.mlist type=vect pattern="verify_points_class*"`
if [ `echo $LIST | wc -w` -eq 0 ]; then
	g.message -e "verify point layer was not found."
	exit 1
fi

for P in $LIST; do

	v.to.rast input=${P} output="rtemp_random_rast" use=attr column=value
	r.mapcalc "rtemp_random_cell = int(rtemp_random_rast)"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	r.to.vect input="rtemp_random_cell" output="rtemp_random_cell" feature=area
	v.out.ogr input="rtemp_random_cell" type="area" dsn="${PREFIX}_"`echo ${P} | cut -d '_' -f 3`".kml" format=KML
	if [ $? -ne 0 ]; then
		exit 1
	fi
	g.mremove -f vect="rtemp_*"
	g.mremove -f rast="rtemp_*"

#	v.type input=${POINTLAYER} output="rtemp_cent" type="point to centroid"
#	v.patch input="rtemp_random_cell,rtemp_cent" output="rtemp_patch"

done
