#!/bin/bash

if [ $# != 2 ]; then
	echo "modis_verify_points usage: [classified raster] [num points]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

CLASSIFIEDMAP=$1
NUMPOINTS=$2
POINTLAYER_NAME="verify_points"

eval `g.findfile element=CELL file=$CLASSIFIEDMAP`
if [ ! $file ]; then
	g.message -e "training raster layer [${CLASSIFIEDMAP}] was not found."
	exit 1
fi

#v.random output=$POINTLAYER_NAME n=$2
#v.db.addtable map=$POINTLAYER_NAME table=$POINTLAYER_NAME columns="class integer"
#v.what.rast vector=$POINTLAYER_NAME raster=$CLASSIFIEDMAP column="class"

if [ `g.mlist pattern="MASK"` ]; then
	g.rename rast="MASK,MASK_"
fi

for C in `r.describe -1 -n map=$CLASSIFIEDMAP 2> /dev/null`; do

	r.mask input=${CLASSIFIEDMAP} maskcats=${C}
	r.random input=${CLASSIFIEDMAP} vector_output=${POINTLAYER_NAME}_class${C} n=${NUMPOINTS}
#	v.extract input=$POINTLAYER_NAME output=${POINTLAYER_NAME}_class_${C} where="class=${C}"
	g.remove rast="MASK"

done

if [ `g.mlist pattern="MASK_"` ]; then
	g.rename rast="MASK_,MASK"
fi
