
import sys, os
import ogr, osr

def main():
	"""Main function"""

	west = sys.argv[1]
	south = sys.argv[2]
	east = sys.argv[3]
	north = sys.argv[4]

	#
	# Create selection rectangle in MODIS sinusoidal space.
	#
	srs_orig = osr.SpatialReference()
	srs_orig.ImportFromEPSG(4612)
	srs_trans = osr.SpatialReference()
	srs_trans.ImportFromProj4("+proj=sinu +lon_0=0 +x_0=0 +y_0=0 +a=6371007.181 +b=6371007.181 +units=m +no_defs")

	wkt = "POLYGON((" + west + " " + north + "," + west + " " + south + "," + east + " " + south + "," + east + " " + north + "," + west + " " + north + "))"
	rect = ogr.CreateGeometryFromWkt(wkt, srs_orig)
	ogr.Geometry.TransformTo(rect, srs_trans)

	#
	# Load MODIS grid file.
	#
	ogr.RegisterAll()

	ds = ogr.Open(os.path.dirname(sys.argv[0]) + "/modis_grid.sqlite")
	print os.path.dirname(sys.argv[0]) + "/modis_grid.sqlite"
	if ds is None:
		print "Open failed.\n"
		sys.exit(1)

	layer = ds.GetLayerByName("modis_sinusoidal_grid_world")
	layer.SetSpatialFilter(rect)

	#
	# Search overlap frames and print result.
	#
	mframe = layer.GetNextFeature()
	while mframe is not None:
		print "h%02dv%02d" % (mframe.GetFieldAsInteger(mframe.GetFieldIndex("h")), mframe.GetFieldAsInteger(mframe.GetFieldIndex("v")))
		mframe = layer.GetNextFeature()

if __name__ == "__main__":
    main()
