#!/bin/bash

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		echo "ERROR: modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

#
# calc NDIV of each scene.
#
echo "calculate NDVI of each scene..."
SCENELIST=`g.mlist type=rast pattern="viirs_*" | cut -d "_" -f 1-5 | sort | uniq`
for S in $SCENELIST; do

	BAND1=${S}_band1
	BAND2=${S}_band2
	eval `g.findfile element=CELL file=$BAND1`
	if [ ! "$file" ]; then
		g.message -e "VIIRS Band1 <$BAND1> does not exist."
		exit 1
	fi
	eval `g.findfile element=CELL file=$BAND2`
	if [ ! "$file" ]; then
		g.message -e "VIIRS Band2 <$BAND2> does not exist."
		exit 1
	fi
	r.mapcalc "${S}_ndvi = (float(${BAND2}) - float(${BAND1}))/(float(${BAND2})+float(${BAND1}))"
	if [ $? -ne 0 ]; then
		exit 1
	fi

done

DATELIST=`g.mlist type=rast pattern="viirs_*" | cut -d "_" -f 2 | sort | uniq`
if [ `echo $DATELIST | wc -w` -eq 0 ]; then
	g.message -e "No raster layer of VIIRS was not found."
	exit 1
fi

echo "merge images of the same days and same band..."
for D in $DATELIST; do

	#
	# create MAX-NDVI layer of each day.
	#
	FILELIST=`g.mlist type=rast pattern="viirs_${D}_*_ndvi" separator=comma`
	MAXNDVI="maxndvi_${D}"
	r.mapcalc "${MAXNDVI} = max(${FILELIST})"
	if [ $? -ne 0 ]; then
		exit 1
	fi

	#
	# merge images of the same days and same band.
	#
	BANDLIST=`g.mlist type=rast pattern="viirs_${D}_*" | cut -d "_" -f 6 | sort | uniq | grep "band"`
	for B in $BANDLIST; do

		FILELIST=`g.mlist type=rast pattern="viirs_*" | grep "$D" | grep "$B"`
		for L in $FILELIST; do
			NDVI=`echo $L | sed "s/${B}/ndvi/"`
			r.mapcalc "temp_${L} = if(${NDVI}==${MAXNDVI},${L},null())"
			if [ $? -ne 0 ]; then
				exit 1
			fi
		done
		r.patch input=`g.mlist type=rast pattern="temp_*" separator=comma` output="viirs_${D}_${B}"
		g.mremove -f rast="temp_*"
	done

done
